@@ -1,14 +1,12 @@
 package Sietima::Role::Headers;
 use Moo::Role;
-use Try::Tiny;
 use Sietima::Policy;
 use Sietima::HeaderURI;
-use Email::Address;
 use Types::Standard qw(Str);
 use Sietima::Types qw(HeaderUriFromThings);
 use namespace::clean;
 
-our $VERSION = '1.0.5'; # VERSION
+our $VERSION = '1.1.0'; # VERSION
 # ABSTRACT: adds standard list-related headers to messages
 
 
@@ -89,7 +87,7 @@ Sietima::Role::Headers - adds standard list-related headers to messages
 
 =head1 VERSION
 
-version 1.0.5
+version 1.1.0
 
 =head1 SYNOPSIS
 
@@ -174,7 +172,7 @@ Gianni Ceccarelli <dakkar@thenautilus.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Gianni Ceccarelli <dakkar@thenautilus.net>.
+This software is copyright (c) 2023 by Gianni Ceccarelli <dakkar@thenautilus.net>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
