@@ -4,10 +4,10 @@ use Sietima::Policy;
 use Email::Address;
 use List::AllUtils qw(any);
 use Types::Standard qw(Object CodeRef);
-use Type::Params qw(compile);
+use Type::Params -sigs;
 use namespace::clean;
 
-our $VERSION = '1.0.5'; # VERSION
+our $VERSION = '1.1.0'; # VERSION
 # ABSTRACT: base role for "closed" lists
 
 
@@ -28,9 +28,11 @@ around munge_mail => sub ($orig,$self,$mail) {
 };
 
 
+signature_for ignoring_subscriberonly => (
+    method => Object,
+    positional => [ CodeRef ],
+);
 sub ignoring_subscriberonly($self,$code) {
-    state $check = compile(Object,CodeRef); $check->(@_);
-
     local $let_it_pass = 1;
     return $code->($self);
 }
@@ -49,7 +51,7 @@ Sietima::Role::SubscriberOnly - base role for "closed" lists
 
 =head1 VERSION
 
-version 1.0.5
+version 1.1.0
 
 =head1 SYNOPSIS
 
@@ -111,7 +113,7 @@ Gianni Ceccarelli <dakkar@thenautilus.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Gianni Ceccarelli <dakkar@thenautilus.net>.
+This software is copyright (c) 2023 by Gianni Ceccarelli <dakkar@thenautilus.net>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
